==> v1.15.0-rc.1.tar.gz: crossplane-runtime/README.md <==
# crossplane-runtime
[![CI](https://github.com/crossplane/crossplane-runtime/actions/workflows/ci.yml/badge.svg)](https://github.com/crossplane/crossplane-runtime/actions/workflows/ci.yml) ![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/crossplane/crossplane-runtime) [![Godoc](https://img.shields.io/badge/godoc-reference-blue.svg)](https://godoc.org/github.com/crossplane/crossplane-runtime)

## Overview

crossplane-runtime is a set of go libraries used to build Kubernetes controllers
in Crossplane and its related stacks. Take a look at our [developer guide] and
[API documentation] for help getting started with crossplane-runtime.

## Contributing

crossplane-runtime is a community driven project and we welcome contributions.
See the Crossplane [contributing] guidelines to get started.

## Report a Bug

For filing bugs, suggesting improvements, or requesting new features, please
open an [issue].

## Contact

Please use the following to reach members of the community:

- Slack: Join our [slack channel]
- Forums: [crossplane-dev]
- Twitter: [@crossplane_io]
- Email: [info@crossplane.io]

## Roadmap

crossplane-runtime goals and milestones are currently tracked in Crossplane's
[roadmap].

## Governance and Owners

crossplane-runtime is run according to the same [governance] and [ownership]
structure as the core Crossplane project.

## Code of Conduct

crossplane-runtime adheres to the same [code of conduct] as the core Crossplane
project.

## Licensing

crossplane-runtime is under the Apache 2.0 license.

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fcrossplane%2Fcrossplane-runtime.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fcrossplane%2Fcrossplane-runtime?ref=badge_large)

[developer guide]: https://github.com/crossplane/crossplane/tree/master/contributing
[API documentation]: https://godoc.org/github.com/crossplane/crossplane-runtime
[contributing]: https://github.com/crossplane/crossplane/blob/master/CONTRIBUTING.md
[issue]: https://github.com/crossplane/crossplane-runtime/issues
[slack channel]: https://slack.crossplane.io
[crossplane-dev]: https://groups.google.com/forum/#!forum/crossplane-dev
[@crossplane_io]: https://twitter.com/crossplane_io
[info@crossplane.io]: mailto:info@crossplane.io
[roadmap]: https://github.com/crossplane/crossplane/blob/master/ROADMAP.md
[governance]: https://github.com/crossplane/crossplane/blob/master/GOVERNANCE.md
[ownership]: https://github.com/crossplane/crossplane/blob/master/OWNERS.md
[code of conduct]: https://github.com/crossplane/crossplane/blob/master/CODE_OF_CONDUCT.md

==> v1.19.0-rc.0.tar.gz: crossplane-runtime/README.md <==
# crossplane-runtime
[![CI](https://github.com/crossplane/crossplane-runtime/actions/workflows/ci.yml/badge.svg)](https://github.com/crossplane/crossplane-runtime/actions/workflows/ci.yml) ![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/crossplane/crossplane-runtime) [![Godoc](https://img.shields.io/badge/godoc-reference-blue.svg)](https://godoc.org/github.com/crossplane/crossplane-runtime)

## Overview

crossplane-runtime is a set of go libraries used to build Kubernetes controllers
in Crossplane and its related stacks. Take a look at our [developer guide] and
[API documentation] for help getting started with crossplane-runtime.

## Contributing

crossplane-runtime is a community driven project and we welcome contributions.
See the Crossplane [contributing] guidelines to get started.

## Report a Bug

For filing bugs, suggesting improvements, or requesting new features, please
open an [issue].

## Contact

Please use the following to reach members of the community:

- Slack: Join our [slack channel]
- Forums: [crossplane-dev]
- Twitter: [@crossplane_io]
- Email: [info@crossplane.io]

## Roadmap

crossplane-runtime goals and milestones are currently tracked in Crossplane's
[roadmap].

## Governance and Owners

crossplane-runtime is run according to the same [governance] and [ownership]
structure as the core Crossplane project.

## Code of Conduct

crossplane-runtime adheres to the same [code of conduct] as the core Crossplane
project.

## Licensing

crossplane-runtime is under the Apache 2.0 license.

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fcrossplane%2Fcrossplane-runtime.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fcrossplane%2Fcrossplane-runtime?ref=badge_large)

[developer guide]: https://github.com/crossplane/crossplane/tree/main/contributing
[API documentation]: https://godoc.org/github.com/crossplane/crossplane-runtime
[contributing]: https://github.com/crossplane/crossplane/blob/main/CONTRIBUTING.md
[issue]: https://github.com/crossplane/crossplane-runtime/issues
[slack channel]: https://slack.crossplane.io
[crossplane-dev]: https://groups.google.com/forum/#!forum/crossplane-dev
[@crossplane_io]: https://twitter.com/crossplane_io
[info@crossplane.io]: mailto:info@crossplane.io
[roadmap]: https://github.com/crossplane/crossplane/blob/main/ROADMAP.md
[governance]: https://github.com/crossplane/crossplane/blob/main/GOVERNANCE.md
[ownership]: https://github.com/crossplane/crossplane/blob/main/OWNERS.md
[code of conduct]: https://github.com/crossplane/crossplane/blob/main/CODE_OF_CONDUCT.md
